modified by ohneta

Dependents:   HelloESP8266Interface_mine

Fork of NetworkSocketAPI by NetworkSocketAPI

Revision:
9:26b257519de9
Parent:
8:4b7f97a5597b
Child:
11:47c32687a44c
--- a/SocketInterface.h	Wed Jun 17 23:37:43 2015 +0000
+++ b/SocketInterface.h	Thu Jun 18 15:24:55 2015 +0000
@@ -107,11 +107,11 @@
      */
     virtual int32_t accept(const Endpoint &endpoint) const = 0;
 
     /** In client mode, connect to a remote host
         @param endpoint The endpoint we want to connect to
         @return 0 on success, -1 on failure (when an hostname cannot be resolved by DNS).
      */
-    virtual int32_t connect(const Endpoint &endpoint) const = 0;
+    virtual int32_t open(const Endpoint &endpoint) const = 0;
     
     /** In client or server mode send data
         @param data A buffer of data to send
@@ -107,11 +107,11 @@
     virtual int32_t accept(const Endpoint &endpoint) const = 0;
 
-    /** In client mode, connect to a remote host
+    /** In client mode, open a connection to a remote host
         @param endpoint The endpoint we want to connect to
         @return 0 on success, -1 on failure (when an hostname cannot be resolved by DNS).